Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Service ¶
type Service struct {
// Name of service.
Name string
// Path of service, command run inside this path.
Path string
// Command is the command to run with args.
Command string
// GoTemplate and Sprig functions are available.
Env map[string]interface{}
// EnvValues is a list of environment variables path from exported config.
EnvValues []string `cfg:"env_values"`
// Inherit environment variables, default is false.
InheritEnv bool `cfg:"inherit_env"`
// Filters is a function to filter stdout.
Filters [][]byte
// FiltersValues is a list of filter variables path from exported config.
FiltersValues []string `cfg:"filters_values"`
// contains filtered or unexported fields
}
func (*Service) SetFilters ¶ added in v0.2.1
func (s *Service) SetFilters()
Click to show internal directories.
Click to hide internal directories.